@@ -21,6 +21,11 @@ from os import environ
 from multiprocessing import Process, Queue
 
 try:
+    from calculate.lib.utils.files import getRunCommands
+    from itertools import ifilter
+
+    if not any(ifilter(lambda x: "/usr/bin/X" in x, getRunCommands())):
+        raise Exception("No X")
     from PyQt5 import QtCore
     from PyQt5 import QtGui
     from PyQt5 import QtWidgets
