@@ -212,7 +212,8 @@ class SizeableDisk(object):
             avail = humanreadableSize(availbytes)
             need = humanreadableSize(needbytes)
             raise VirtualDiskError(
-                _("There is not enough space on this device") + _(": ") +
+                _("There is not enough space on this device "
+                  "to perform the autopartition") + _(": ") +
                 _("{avail} available, need at {need} more").format(
                     avail=avail,
                     need=need))
@@ -1037,6 +1038,7 @@ class SchemeBuilder(object):
         self.minimal_calculate_size = 500 * Sizes().M
         self.update = False
         self.calculate = False
+        self.rootall = False
         self.rounding = 0.01
         self.vgname = "calculate"
 
@@ -1103,16 +1105,24 @@ class SchemeBuilder(object):
     def process(self, volumes_factory):
         volume_builder = self.get_volume_builder(volumes_factory)
         volume_builder.rounding = self.rounding
+        if self.rootall and (self.update or self.calculate):
+            raise SchemeError(
+                _("Root to all free size should not use with update partition "
+                  "or calculate partition"))
         with VolumesSet(volume_builder) as builder:
             if self.swap:
                 builder.create_volume(self.swap_size, "swap",
                                       VolumesBuilder.Purpose.Swap)
-            builder.create_volume(self.root_size, "system1",
-                                  VolumesBuilder.Purpose.MainRoot, None)
-            if self.update:
-                builder.create_volume(self.root_size, "system2",
-                                      VolumesBuilder.Purpose.UpdateRoot)
-            if self.calculate:
-                builder.create_volume(VolumesBuilder.SizeAllFree, "calculate",
-                                      VolumesBuilder.Purpose.Calculate,
-                                      self.minimal_calculate_size)
+            if self.rootall:
+                builder.create_volume(VolumesBuilder.SizeAllFree, "system1",
+                                      VolumesBuilder.Purpose.MainRoot, None)
+            else:
+                builder.create_volume(self.root_size, "system1",
+                                      VolumesBuilder.Purpose.MainRoot, None)
+                if self.update:
+                    builder.create_volume(self.root_size, "system2",
+                                          VolumesBuilder.Purpose.UpdateRoot)
+                if self.calculate:
+                    builder.create_volume(VolumesBuilder.SizeAllFree, "calculate",
+                                          VolumesBuilder.Purpose.Calculate,
+                                          self.minimal_calculate_size)
